# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_spot_exchange_rate_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/aggregates_spot_exchange_rate_v1/request.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n5com.kaiko.sdk.stream.aggregates_spot_exchange_rate_v1P\001Zogithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_spot_exchange_rate_v1;aggregates_spot_exchange_rate_v1\252\002,KaikoSdk.Stream.AggregatesSpotExchangeRateV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9sdk/stream/aggregates_spot_exchange_rate_v1/request.proto\x12\x08kaikosdk\"]\n)StreamAggregatesSpotExchangeRateRequestV1\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x11\n\taggregate\x18\x02 \x01(\t\x12\x0f\n\x07sources\x18\x03 \x01(\x08\x42\xd9\x01\n5com.kaiko.sdk.stream.aggregates_spot_exchange_rate_v1P\x01Zogithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_spot_exchange_rate_v1;aggregates_spot_exchange_rate_v1\xaa\x02,KaikoSdk.Stream.AggregatesSpotExchangeRateV1b\x06proto3'
)




_STREAMAGGREGATESSPOTEXCHANGERATEREQUESTV1 = _descriptor.Descriptor(
  name='StreamAggregatesSpotExchangeRateRequestV1',
  full_name='kaikosdk.StreamAggregatesSpotExchangeRateRequestV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='kaikosdk.StreamAggregatesSpotExchangeRateRequestV1.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregate', full_name='kaikosdk.StreamAggregatesSpotExchangeRateRequestV1.aggregate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sources', full_name='kaikosdk.StreamAggregatesSpotExchangeRateRequestV1.sources', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=164,
)

DESCRIPTOR.message_types_by_name['StreamAggregatesSpotExchangeRateRequestV1'] = _STREAMAGGREGATESSPOTEXCHANGERATEREQUESTV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamAggregatesSpotExchangeRateRequestV1 = _reflection.GeneratedProtocolMessageType('StreamAggregatesSpotExchangeRateRequestV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMAGGREGATESSPOTEXCHANGERATEREQUESTV1,
  '__module__' : 'sdk.stream.aggregates_spot_exchange_rate_v1.request_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamAggregatesSpotExchangeRateRequestV1)
  })
_sym_db.RegisterMessage(StreamAggregatesSpotExchangeRateRequestV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
