# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/core/wrappers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/core/wrappers.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\022com.kaiko.sdk.coreP\001Z0github.com/challengerdeep/kaiko-go-sdk/core;core\252\002\rKaikoSdk.Core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17sdk/core/wrappers.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\";\n\x0eTimestampValue\x12)\n\x05value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampBX\n\x12\x63om.kaiko.sdk.coreP\x01Z0github.com/challengerdeep/kaiko-go-sdk/core;core\xaa\x02\rKaikoSdk.Coreb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_TIMESTAMPVALUE = _descriptor.Descriptor(
  name='TimestampValue',
  full_name='kaikosdk.TimestampValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='kaikosdk.TimestampValue.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=129,
)

_TIMESTAMPVALUE.fields_by_name['value'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['TimestampValue'] = _TIMESTAMPVALUE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimestampValue = _reflection.GeneratedProtocolMessageType('TimestampValue', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMPVALUE,
  '__module__' : 'sdk.core.wrappers_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.TimestampValue)
  })
_sym_db.RegisterMessage(TimestampValue)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
