# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/index_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/index_v1/request.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\035com.kaiko.sdk.stream.index_v1P\001Z?github.com/challengerdeep/kaiko-go-sdk/stream/index_v1;index_v1\252\002\027KaikoSdk.Stream.IndexV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!sdk/stream/index_v1/request.proto\x12\x08kaikosdk\"E\n\x1bStreamIndexServiceRequestV1\x12\x12\n\nindex_code\x18\x01 \x01(\t\x12\x12\n\nevent_type\x18\x02 \x01(\tB|\n\x1d\x63om.kaiko.sdk.stream.index_v1P\x01Z?github.com/challengerdeep/kaiko-go-sdk/stream/index_v1;index_v1\xaa\x02\x17KaikoSdk.Stream.IndexV1b\x06proto3'
)




_STREAMINDEXSERVICEREQUESTV1 = _descriptor.Descriptor(
  name='StreamIndexServiceRequestV1',
  full_name='kaikosdk.StreamIndexServiceRequestV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index_code', full_name='kaikosdk.StreamIndexServiceRequestV1.index_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='kaikosdk.StreamIndexServiceRequestV1.event_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=116,
)

DESCRIPTOR.message_types_by_name['StreamIndexServiceRequestV1'] = _STREAMINDEXSERVICEREQUESTV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamIndexServiceRequestV1 = _reflection.GeneratedProtocolMessageType('StreamIndexServiceRequestV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINDEXSERVICEREQUESTV1,
  '__module__' : 'sdk.stream.index_v1.request_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamIndexServiceRequestV1)
  })
_sym_db.RegisterMessage(StreamIndexServiceRequestV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
