# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_spot_exchange_rate_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import source_pb2 as sdk_dot_core_dot_source__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/aggregates_spot_exchange_rate_v1/response.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n5com.kaiko.sdk.stream.aggregates_spot_exchange_rate_v1P\001Zogithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_spot_exchange_rate_v1;aggregates_spot_exchange_rate_v1\252\002,KaikoSdk.Stream.AggregatesSpotExchangeRateV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:sdk/stream/aggregates_spot_exchange_rate_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x15sdk/core/source.proto\"\xc3\x02\n*StreamAggregatesSpotExchangeRateResponseV1\x12\x11\n\taggregate\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\r\n\x05price\x18\x03 \x01(\t\x12\x13\n\x0bsequence_id\x18\x04 \x01(\t\x12R\n\x07sources\x18\x05 \x03(\x0b\x32\x41.kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.SourcesEntry\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03uid\x18\x07 \x01(\t\x1a@\n\x0cSourcesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.kaikosdk.Source:\x02\x38\x01\x42\xd9\x01\n5com.kaiko.sdk.stream.aggregates_spot_exchange_rate_v1P\x01Zogithub.com/challengerdeep/kaiko-go-sdk/stream/aggregates_spot_exchange_rate_v1;aggregates_spot_exchange_rate_v1\xaa\x02,KaikoSdk.Stream.AggregatesSpotExchangeRateV1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,sdk_dot_core_dot_source__pb2.DESCRIPTOR,])




_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY = _descriptor.Descriptor(
  name='SourcesEntry',
  full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.SourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.SourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.SourcesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=388,
  serialized_end=452,
)

_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1 = _descriptor.Descriptor(
  name='StreamAggregatesSpotExchangeRateResponseV1',
  full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aggregate', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.aggregate', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_id', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.sequence_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sources', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.sources', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.timestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.uid', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=452,
)

_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY.fields_by_name['value'].message_type = sdk_dot_core_dot_source__pb2._SOURCE
_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY.containing_type = _STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1
_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1.fields_by_name['sources'].message_type = _STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY
_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['StreamAggregatesSpotExchangeRateResponseV1'] = _STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamAggregatesSpotExchangeRateResponseV1 = _reflection.GeneratedProtocolMessageType('StreamAggregatesSpotExchangeRateResponseV1', (_message.Message,), {

  'SourcesEntry' : _reflection.GeneratedProtocolMessageType('SourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY,
    '__module__' : 'sdk.stream.aggregates_spot_exchange_rate_v1.response_pb2'
    # @@protoc_insertion_point(class_scope:kaikosdk.StreamAggregatesSpotExchangeRateResponseV1.SourcesEntry)
    })
  ,
  'DESCRIPTOR' : _STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1,
  '__module__' : 'sdk.stream.aggregates_spot_exchange_rate_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamAggregatesSpotExchangeRateResponseV1)
  })
_sym_db.RegisterMessage(StreamAggregatesSpotExchangeRateResponseV1)
_sym_db.RegisterMessage(StreamAggregatesSpotExchangeRateResponseV1.SourcesEntry)


DESCRIPTOR._options = None
_STREAMAGGREGATESSPOTEXCHANGERATERESPONSEV1_SOURCESENTRY._options = None
# @@protoc_insertion_point(module_scope)
