# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/market_update_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import wrappers_pb2 as sdk_dot_core_dot_wrappers__pb2
from kaikosdk.stream.market_update_v1 import commodity_pb2 as sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/market_update_v1/response.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n%com.kaiko.sdk.stream.market_update_v1P\001ZOgithub.com/challengerdeep/kaiko-go-sdk/stream/market_update_v1;market_update_v1\252\002\036KaikoSdk.Stream.MarketUpdateV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*sdk/stream/market_update_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17sdk/core/wrappers.proto\x1a+sdk/stream/market_update_v1/commodity.proto\"\xae\x04\n\x1cStreamMarketUpdateResponseV1\x12\x38\n\tcommodity\x18\x01 \x01(\x0e\x32%.kaikosdk.StreamMarketUpdateCommodity\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\r\n\x05\x63lass\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x10\n\x08\x65xchange\x18\x05 \x01(\t\x12\x13\n\x0bsequence_id\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\x01\x12-\n\x0bts_exchange\x18\t \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12/\n\rts_collection\x18\n \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12,\n\x08ts_event\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12R\n\x0bupdate_type\x18\x0c \x01(\x0e\x32=.kaikosdk.StreamMarketUpdateResponseV1.StreamMarketUpdateType\"\x82\x01\n\x16StreamMarketUpdateType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tTRADE_BUY\x10\x01\x12\x0e\n\nTRADE_SELL\x10\x02\x12\x0c\n\x08\x42\x45ST_ASK\x10\x03\x12\x0c\n\x08\x42\x45ST_BID\x10\x04\x12\x0f\n\x0bUPDATED_ASK\x10\x05\x12\x0f\n\x0bUPDATED_BID\x10\x06\x42\x9b\x01\n%com.kaiko.sdk.stream.market_update_v1P\x01ZOgithub.com/challengerdeep/kaiko-go-sdk/stream/market_update_v1;market_update_v1\xaa\x02\x1eKaikoSdk.Stream.MarketUpdateV1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,sdk_dot_core_dot_wrappers__pb2.DESCRIPTOR,sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2.DESCRIPTOR,])



_STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE = _descriptor.EnumDescriptor(
  name='StreamMarketUpdateType',
  full_name='kaikosdk.StreamMarketUpdateResponseV1.StreamMarketUpdateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRADE_BUY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRADE_SELL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEST_ASK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEST_BID', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATED_ASK', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATED_BID', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=588,
  serialized_end=718,
)
_sym_db.RegisterEnumDescriptor(_STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE)


_STREAMMARKETUPDATERESPONSEV1 = _descriptor.Descriptor(
  name='StreamMarketUpdateResponseV1',
  full_name='kaikosdk.StreamMarketUpdateResponseV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commodity', full_name='kaikosdk.StreamMarketUpdateResponseV1.commodity', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='kaikosdk.StreamMarketUpdateResponseV1.amount', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class', full_name='kaikosdk.StreamMarketUpdateResponseV1.class', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='kaikosdk.StreamMarketUpdateResponseV1.code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='kaikosdk.StreamMarketUpdateResponseV1.exchange', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_id', full_name='kaikosdk.StreamMarketUpdateResponseV1.sequence_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='kaikosdk.StreamMarketUpdateResponseV1.id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.StreamMarketUpdateResponseV1.price', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_exchange', full_name='kaikosdk.StreamMarketUpdateResponseV1.ts_exchange', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_collection', full_name='kaikosdk.StreamMarketUpdateResponseV1.ts_collection', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_event', full_name='kaikosdk.StreamMarketUpdateResponseV1.ts_event', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_type', full_name='kaikosdk.StreamMarketUpdateResponseV1.update_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=718,
)

_STREAMMARKETUPDATERESPONSEV1.fields_by_name['commodity'].enum_type = sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2._STREAMMARKETUPDATECOMMODITY
_STREAMMARKETUPDATERESPONSEV1.fields_by_name['ts_exchange'].message_type = sdk_dot_core_dot_wrappers__pb2._TIMESTAMPVALUE
_STREAMMARKETUPDATERESPONSEV1.fields_by_name['ts_collection'].message_type = sdk_dot_core_dot_wrappers__pb2._TIMESTAMPVALUE
_STREAMMARKETUPDATERESPONSEV1.fields_by_name['ts_event'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMMARKETUPDATERESPONSEV1.fields_by_name['update_type'].enum_type = _STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE
_STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE.containing_type = _STREAMMARKETUPDATERESPONSEV1
DESCRIPTOR.message_types_by_name['StreamMarketUpdateResponseV1'] = _STREAMMARKETUPDATERESPONSEV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamMarketUpdateResponseV1 = _reflection.GeneratedProtocolMessageType('StreamMarketUpdateResponseV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMMARKETUPDATERESPONSEV1,
  '__module__' : 'sdk.stream.market_update_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamMarketUpdateResponseV1)
  })
_sym_db.RegisterMessage(StreamMarketUpdateResponseV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
