# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/market_update_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2
from kaikosdk.core import instrument_criteria_pb2 as sdk_dot_core_dot_instrument__criteria__pb2
from kaikosdk.stream.market_update_v1 import commodity_pb2 as sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/market_update_v1/request.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n%com.kaiko.sdk.stream.market_update_v1P\001ZOgithub.com/challengerdeep/kaiko-go-sdk/stream/market_update_v1;market_update_v1\252\002\036KaikoSdk.Stream.MarketUpdateV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)sdk/stream/market_update_v1/request.proto\x12\x08kaikosdk\x1a\x1csdk/core/data_interval.proto\x1a\"sdk/core/instrument_criteria.proto\x1a+sdk/stream/market_update_v1/commodity.proto\"\xbe\x01\n\x1bStreamMarketUpdateRequestV1\x12\x39\n\x13instrument_criteria\x18\x01 \x01(\x0b\x32\x1c.kaikosdk.InstrumentCriteria\x12:\n\x0b\x63ommodities\x18\x02 \x03(\x0e\x32%.kaikosdk.StreamMarketUpdateCommodity\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataIntervalB\x9b\x01\n%com.kaiko.sdk.stream.market_update_v1P\x01ZOgithub.com/challengerdeep/kaiko-go-sdk/stream/market_update_v1;market_update_v1\xaa\x02\x1eKaikoSdk.Stream.MarketUpdateV1b\x06proto3'
  ,
  dependencies=[sdk_dot_core_dot_data__interval__pb2.DESCRIPTOR,sdk_dot_core_dot_instrument__criteria__pb2.DESCRIPTOR,sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2.DESCRIPTOR,])




_STREAMMARKETUPDATEREQUESTV1 = _descriptor.Descriptor(
  name='StreamMarketUpdateRequestV1',
  full_name='kaikosdk.StreamMarketUpdateRequestV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instrument_criteria', full_name='kaikosdk.StreamMarketUpdateRequestV1.instrument_criteria', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commodities', full_name='kaikosdk.StreamMarketUpdateRequestV1.commodities', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='kaikosdk.StreamMarketUpdateRequestV1.interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=357,
)

_STREAMMARKETUPDATEREQUESTV1.fields_by_name['instrument_criteria'].message_type = sdk_dot_core_dot_instrument__criteria__pb2._INSTRUMENTCRITERIA
_STREAMMARKETUPDATEREQUESTV1.fields_by_name['commodities'].enum_type = sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2._STREAMMARKETUPDATECOMMODITY
_STREAMMARKETUPDATEREQUESTV1.fields_by_name['interval'].message_type = sdk_dot_core_dot_data__interval__pb2._DATAINTERVAL
DESCRIPTOR.message_types_by_name['StreamMarketUpdateRequestV1'] = _STREAMMARKETUPDATEREQUESTV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamMarketUpdateRequestV1 = _reflection.GeneratedProtocolMessageType('StreamMarketUpdateRequestV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMMARKETUPDATEREQUESTV1,
  '__module__' : 'sdk.stream.market_update_v1.request_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamMarketUpdateRequestV1)
  })
_sym_db.RegisterMessage(StreamMarketUpdateRequestV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
