# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/index_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/index_v1/response.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\035com.kaiko.sdk.stream.index_v1P\001Z?github.com/challengerdeep/kaiko-go-sdk/stream/index_v1;index_v1\252\002\027KaikoSdk.Stream.IndexV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"sdk/stream/index_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1csdk/core/data_interval.proto\"\x83\x01\n$StreamIndexServiceResponsePercentage\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x38\n\x05pairs\x18\x03 \x03(\x0b\x32).kaikosdk.StreamIndexServiceResponsePairs\"\x85\x01\n\x1fStreamIndexServiceResponsePairs\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12\x44\n\x0binstruments\x18\x03 \x03(\x0b\x32/.kaikosdk.StreamIndexServiceResponseInstruments\"X\n%StreamIndexServiceResponseInstruments\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x01\"\xe3\x01\n\x1cStreamIndexServiceResponseV1\x12\x12\n\nindex_code\x18\x01 \x01(\t\x12\x12\n\nevent_type\x18\x02 \x01(\t\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12\x43\n\x0bpercentages\x18\x04 \x03(\x0b\x32..kaikosdk.StreamIndexServiceResponsePercentage\x12,\n\x08ts_event\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB|\n\x1d\x63om.kaiko.sdk.stream.index_v1P\x01Z?github.com/challengerdeep/kaiko-go-sdk/stream/index_v1;index_v1\xaa\x02\x17KaikoSdk.Stream.IndexV1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,sdk_dot_core_dot_data__interval__pb2.DESCRIPTOR,])




_STREAMINDEXSERVICERESPONSEPERCENTAGE = _descriptor.Descriptor(
  name='StreamIndexServiceResponsePercentage',
  full_name='kaikosdk.StreamIndexServiceResponsePercentage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentage', full_name='kaikosdk.StreamIndexServiceResponsePercentage.percentage', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.StreamIndexServiceResponsePercentage.price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pairs', full_name='kaikosdk.StreamIndexServiceResponsePercentage.pairs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=243,
)


_STREAMINDEXSERVICERESPONSEPAIRS = _descriptor.Descriptor(
  name='StreamIndexServiceResponsePairs',
  full_name='kaikosdk.StreamIndexServiceResponsePairs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pair', full_name='kaikosdk.StreamIndexServiceResponsePairs.pair', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='kaikosdk.StreamIndexServiceResponsePairs.weight', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instruments', full_name='kaikosdk.StreamIndexServiceResponsePairs.instruments', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=379,
)


_STREAMINDEXSERVICERESPONSEINSTRUMENTS = _descriptor.Descriptor(
  name='StreamIndexServiceResponseInstruments',
  full_name='kaikosdk.StreamIndexServiceResponseInstruments',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange', full_name='kaikosdk.StreamIndexServiceResponseInstruments.exchange', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.StreamIndexServiceResponseInstruments.price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='kaikosdk.StreamIndexServiceResponseInstruments.volume', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=381,
  serialized_end=469,
)


_STREAMINDEXSERVICERESPONSEV1 = _descriptor.Descriptor(
  name='StreamIndexServiceResponseV1',
  full_name='kaikosdk.StreamIndexServiceResponseV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index_code', full_name='kaikosdk.StreamIndexServiceResponseV1.index_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='kaikosdk.StreamIndexServiceResponseV1.event_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='kaikosdk.StreamIndexServiceResponseV1.interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentages', full_name='kaikosdk.StreamIndexServiceResponseV1.percentages', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_event', full_name='kaikosdk.StreamIndexServiceResponseV1.ts_event', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=472,
  serialized_end=699,
)

_STREAMINDEXSERVICERESPONSEPERCENTAGE.fields_by_name['pairs'].message_type = _STREAMINDEXSERVICERESPONSEPAIRS
_STREAMINDEXSERVICERESPONSEPAIRS.fields_by_name['instruments'].message_type = _STREAMINDEXSERVICERESPONSEINSTRUMENTS
_STREAMINDEXSERVICERESPONSEV1.fields_by_name['interval'].message_type = sdk_dot_core_dot_data__interval__pb2._DATAINTERVAL
_STREAMINDEXSERVICERESPONSEV1.fields_by_name['percentages'].message_type = _STREAMINDEXSERVICERESPONSEPERCENTAGE
_STREAMINDEXSERVICERESPONSEV1.fields_by_name['ts_event'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['StreamIndexServiceResponsePercentage'] = _STREAMINDEXSERVICERESPONSEPERCENTAGE
DESCRIPTOR.message_types_by_name['StreamIndexServiceResponsePairs'] = _STREAMINDEXSERVICERESPONSEPAIRS
DESCRIPTOR.message_types_by_name['StreamIndexServiceResponseInstruments'] = _STREAMINDEXSERVICERESPONSEINSTRUMENTS
DESCRIPTOR.message_types_by_name['StreamIndexServiceResponseV1'] = _STREAMINDEXSERVICERESPONSEV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamIndexServiceResponsePercentage = _reflection.GeneratedProtocolMessageType('StreamIndexServiceResponsePercentage', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINDEXSERVICERESPONSEPERCENTAGE,
  '__module__' : 'sdk.stream.index_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamIndexServiceResponsePercentage)
  })
_sym_db.RegisterMessage(StreamIndexServiceResponsePercentage)

StreamIndexServiceResponsePairs = _reflection.GeneratedProtocolMessageType('StreamIndexServiceResponsePairs', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINDEXSERVICERESPONSEPAIRS,
  '__module__' : 'sdk.stream.index_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamIndexServiceResponsePairs)
  })
_sym_db.RegisterMessage(StreamIndexServiceResponsePairs)

StreamIndexServiceResponseInstruments = _reflection.GeneratedProtocolMessageType('StreamIndexServiceResponseInstruments', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINDEXSERVICERESPONSEINSTRUMENTS,
  '__module__' : 'sdk.stream.index_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamIndexServiceResponseInstruments)
  })
_sym_db.RegisterMessage(StreamIndexServiceResponseInstruments)

StreamIndexServiceResponseV1 = _reflection.GeneratedProtocolMessageType('StreamIndexServiceResponseV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINDEXSERVICERESPONSEV1,
  '__module__' : 'sdk.stream.index_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamIndexServiceResponseV1)
  })
_sym_db.RegisterMessage(StreamIndexServiceResponseV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
