# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/core/envelope_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/core/envelope_status.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\022com.kaiko.sdk.coreP\001Z0github.com/challengerdeep/kaiko-go-sdk/core;core\252\002\rKaikoSdk.Core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1esdk/core/envelope_status.proto\x12\x08kaikosdk*5\n\x0e\x45nvelopeStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x42X\n\x12\x63om.kaiko.sdk.coreP\x01Z0github.com/challengerdeep/kaiko-go-sdk/core;core\xaa\x02\rKaikoSdk.Coreb\x06proto3'
)

_ENVELOPESTATUS = _descriptor.EnumDescriptor(
  name='EnvelopeStatus',
  full_name='kaikosdk.EnvelopeStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=44,
  serialized_end=97,
)
_sym_db.RegisterEnumDescriptor(_ENVELOPESTATUS)

EnvelopeStatus = enum_type_wrapper.EnumTypeWrapper(_ENVELOPESTATUS)
UNKNOWN = 0
ERROR = 1
SUCCESS = 2


DESCRIPTOR.enum_types_by_name['EnvelopeStatus'] = _ENVELOPESTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
