# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/core/source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import source_data_pb2 as sdk_dot_core_dot_source__data__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/core/source.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\022com.kaiko.sdk.coreP\001Z0github.com/challengerdeep/kaiko-go-sdk/core;core\252\002\rKaikoSdk.Core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15sdk/core/source.proto\x12\x08kaikosdk\x1a\x1asdk/core/source_data.proto\";\n\x06Source\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.kaikosdk.SourceData\x12\r\n\x05price\x18\x02 \x01(\tBX\n\x12\x63om.kaiko.sdk.coreP\x01Z0github.com/challengerdeep/kaiko-go-sdk/core;core\xaa\x02\rKaikoSdk.Coreb\x06proto3'
  ,
  dependencies=[sdk_dot_core_dot_source__data__pb2.DESCRIPTOR,])




_SOURCE = _descriptor.Descriptor(
  name='Source',
  full_name='kaikosdk.Source',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='kaikosdk.Source.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.Source.price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=122,
)

_SOURCE.fields_by_name['data'].message_type = sdk_dot_core_dot_source__data__pb2._SOURCEDATA
DESCRIPTOR.message_types_by_name['Source'] = _SOURCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Source = _reflection.GeneratedProtocolMessageType('Source', (_message.Message,), {
  'DESCRIPTOR' : _SOURCE,
  '__module__' : 'sdk.core.source_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.Source)
  })
_sym_db.RegisterMessage(Source)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
