# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/trades_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import wrappers_pb2 as sdk_dot_core_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/trades_v1/response.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\036com.kaiko.sdk.stream.trades_v1P\001ZAgithub.com/challengerdeep/kaiko-go-sdk/stream/trades_v1;trades_v1\252\002\030KaikoSdk.Stream.TradesV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#sdk/stream/trades_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17sdk/core/wrappers.proto\"\x94\x04\n\x16StreamTradesResponseV1\x12Y\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32:.kaikosdk.StreamTradesResponseV1.AdditionalPropertiesEntry\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\r\n\x05\x63lass\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x10\n\x08\x65xchange\x18\x05 \x01(\t\x12\x13\n\x0bsequence_id\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\x01\x12\x38\n\x04side\x18\t \x01(\x0e\x32*.kaikosdk.StreamTradesResponseV1.TradeSide\x12-\n\x0bts_exchange\x18\n \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12/\n\rts_collection\x18\x0b \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12,\n\x08ts_event\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\tTradeSide\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x42UY\x10\x01\x12\x08\n\x04SELL\x10\x02\x42\x80\x01\n\x1e\x63om.kaiko.sdk.stream.trades_v1P\x01ZAgithub.com/challengerdeep/kaiko-go-sdk/stream/trades_v1;trades_v1\xaa\x02\x18KaikoSdk.Stream.TradesV1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,sdk_dot_core_dot_wrappers__pb2.DESCRIPTOR,])



_STREAMTRADESRESPONSEV1_TRADESIDE = _descriptor.EnumDescriptor(
  name='TradeSide',
  full_name='kaikosdk.StreamTradesResponseV1.TradeSide',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SELL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=597,
  serialized_end=640,
)
_sym_db.RegisterEnumDescriptor(_STREAMTRADESRESPONSEV1_TRADESIDE)


_STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY = _descriptor.Descriptor(
  name='AdditionalPropertiesEntry',
  full_name='kaikosdk.StreamTradesResponseV1.AdditionalPropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='kaikosdk.StreamTradesResponseV1.AdditionalPropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='kaikosdk.StreamTradesResponseV1.AdditionalPropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=595,
)

_STREAMTRADESRESPONSEV1 = _descriptor.Descriptor(
  name='StreamTradesResponseV1',
  full_name='kaikosdk.StreamTradesResponseV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='additional_properties', full_name='kaikosdk.StreamTradesResponseV1.additional_properties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='kaikosdk.StreamTradesResponseV1.amount', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class', full_name='kaikosdk.StreamTradesResponseV1.class', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='kaikosdk.StreamTradesResponseV1.code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='kaikosdk.StreamTradesResponseV1.exchange', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_id', full_name='kaikosdk.StreamTradesResponseV1.sequence_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='kaikosdk.StreamTradesResponseV1.id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='kaikosdk.StreamTradesResponseV1.price', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side', full_name='kaikosdk.StreamTradesResponseV1.side', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_exchange', full_name='kaikosdk.StreamTradesResponseV1.ts_exchange', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_collection', full_name='kaikosdk.StreamTradesResponseV1.ts_collection', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_event', full_name='kaikosdk.StreamTradesResponseV1.ts_event', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY, ],
  enum_types=[
    _STREAMTRADESRESPONSEV1_TRADESIDE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=640,
)

_STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY.containing_type = _STREAMTRADESRESPONSEV1
_STREAMTRADESRESPONSEV1.fields_by_name['additional_properties'].message_type = _STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY
_STREAMTRADESRESPONSEV1.fields_by_name['side'].enum_type = _STREAMTRADESRESPONSEV1_TRADESIDE
_STREAMTRADESRESPONSEV1.fields_by_name['ts_exchange'].message_type = sdk_dot_core_dot_wrappers__pb2._TIMESTAMPVALUE
_STREAMTRADESRESPONSEV1.fields_by_name['ts_collection'].message_type = sdk_dot_core_dot_wrappers__pb2._TIMESTAMPVALUE
_STREAMTRADESRESPONSEV1.fields_by_name['ts_event'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMTRADESRESPONSEV1_TRADESIDE.containing_type = _STREAMTRADESRESPONSEV1
DESCRIPTOR.message_types_by_name['StreamTradesResponseV1'] = _STREAMTRADESRESPONSEV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamTradesResponseV1 = _reflection.GeneratedProtocolMessageType('StreamTradesResponseV1', (_message.Message,), {

  'AdditionalPropertiesEntry' : _reflection.GeneratedProtocolMessageType('AdditionalPropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY,
    '__module__' : 'sdk.stream.trades_v1.response_pb2'
    # @@protoc_insertion_point(class_scope:kaikosdk.StreamTradesResponseV1.AdditionalPropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _STREAMTRADESRESPONSEV1,
  '__module__' : 'sdk.stream.trades_v1.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamTradesResponseV1)
  })
_sym_db.RegisterMessage(StreamTradesResponseV1)
_sym_db.RegisterMessage(StreamTradesResponseV1.AdditionalPropertiesEntry)


DESCRIPTOR._options = None
_STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)
