# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/market_update_v1/commodity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/market_update_v1/commodity.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n%com.kaiko.sdk.stream.market_update_v1P\001ZOgithub.com/challengerdeep/kaiko-go-sdk/stream/market_update_v1;market_update_v1\252\002\036KaikoSdk.Stream.MarketUpdateV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+sdk/stream/market_update_v1/commodity.proto\x12\x08kaikosdk*o\n\x1bStreamMarketUpdateCommodity\x12\x10\n\x0cSMUC_UNKNOWN\x10\x00\x12\x0e\n\nSMUC_TRADE\x10\x01\x12\x14\n\x10SMUC_TOP_OF_BOOK\x10\x02\x12\x18\n\x14SMUC_FULL_ORDER_BOOK\x10\x03\x42\x9b\x01\n%com.kaiko.sdk.stream.market_update_v1P\x01ZOgithub.com/challengerdeep/kaiko-go-sdk/stream/market_update_v1;market_update_v1\xaa\x02\x1eKaikoSdk.Stream.MarketUpdateV1b\x06proto3'
)

_STREAMMARKETUPDATECOMMODITY = _descriptor.EnumDescriptor(
  name='StreamMarketUpdateCommodity',
  full_name='kaikosdk.StreamMarketUpdateCommodity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SMUC_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMUC_TRADE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMUC_TOP_OF_BOOK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMUC_FULL_ORDER_BOOK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57,
  serialized_end=168,
)
_sym_db.RegisterEnumDescriptor(_STREAMMARKETUPDATECOMMODITY)

StreamMarketUpdateCommodity = enum_type_wrapper.EnumTypeWrapper(_STREAMMARKETUPDATECOMMODITY)
SMUC_UNKNOWN = 0
SMUC_TRADE = 1
SMUC_TOP_OF_BOOK = 2
SMUC_FULL_ORDER_BOOK = 3


DESCRIPTOR.enum_types_by_name['StreamMarketUpdateCommodity'] = _STREAMMARKETUPDATECOMMODITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
